@@ -6,8 +6,7 @@ use 5.008001;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build or find automake
-our $VERSION = '0.12'; # VERSION
-
+our $VERSION = '0.14'; # VERSION
 
 
 
@@ -28,7 +27,7 @@ Alien::automake - Build or find automake
 
 =head1 VERSION
 
-version 0.12
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -48,9 +47,27 @@ will use that.  If it cannot be found, the source code will be downloaded
 from the internet and it will be installed in a private share location
 for the use of other modules.
 
+=head1 CAVEATS
+
+This module is currently configured to I<always> do a share install.  This is because C<system> installs for this alien are not reliable.  Please see 
+this issue for details: L<https://github.com/plicease/Alien-autoconf/issues/2> (the issue is for autoconf, but relates to automake as well).  The good
+news is that most of the time you shouldn't need this module I<unless> you are building another alien from source.  If your system provides the package
+that is targeted by the upstream alien I recommend using that.  If you are packaging system packages for your platform then I recommend making sure the
+upstream alien uses the system library so you won't need to install this module.
+
 =head1 SEE ALSO
 
-L<Alien>, L<Alien::Base>, L<Alien::Build::Manual::AlienUser>
+=over 4
+
+=item L<alienfile>
+
+=item L<Alien::Build>
+
+=item L<Alien::Build>
+
+=item L<Alien::Autotools>
+
+=back
 
 =head1 AUTHOR
 
